
/*--------------------------------------------------------------*/
    /* #region - Product Listing - Padding Options */
/*--------------------------------------------------------------*/

    .woocommerce ul.products.product-padding-content li.product .product-details { padding-left: 15px; padding-right: 15px; padding-top: 10px; padding-bottom: 10px; }

    .woocommerce ul.products.product-padding-content li.product .product-wrapper { padding: 0; }

    .woocommerce ul.products.product-padding-content li.product .product-thumb .image { margin: 0; }

/* #endregion - Product Listing - Padding Options */